==> haskell-lexer-1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.1
visibility:           public
id:                   haskell-lexer-1.1-IuECx4lVoA9ICiyK8fiu7V
key:                  haskell-lexer-1.1-IuECx4lVoA9ICiyK8fiu7V
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  7bfb53bc09a9806d5270498dc98886f4
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-9.0.1/site-local/haskell-lexer-1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/haskell-lexer-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/haskell-lexer-1.1
hs-libraries:         HShaskell-lexer-1.1-IuECx4lVoA9ICiyK8fiu7V
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lexer-1.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.1
visibility:           public
id:                   haskell-lexer-1.1-CfqUww4ysLq8GMrrav0JAz
key:                  haskell-lexer-1.1-CfqUww4ysLq8GMrrav0JAz
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  6be6ff9acd93c136f4bf802a5d589f9e
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-9.0.2/site-local/haskell-lexer-1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/haskell-lexer-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/haskell-lexer-1.1
hs-libraries:         HShaskell-lexer-1.1-CfqUww4ysLq8GMrrav0JAz
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
